print("import: 'cleo'")
import cleo

print("import: 'cleo.commands'")
import cleo.commands

print("import: 'cleo.commands.completions'")
import cleo.commands.completions

print("import: 'cleo.config'")
import cleo.config

print("import: 'cleo.io'")
import cleo.io

print("import: 'cleo.testers'")
import cleo.testers

